".First.lib" <-
function (lib, pkg) 
{library.dynam("fields",pkg, lib)
cat("fields is loaded use help(fields) for an overview of this library", 
fill=TRUE)
}
